@@ -25,7 +25,7 @@ main(int argc, char *argv[])
 
 	assl_initialize();
 
-	c = assl_alloc_context(ASSL_M_TLSV1_CLIENT, 0);
+	c = assl_alloc_context(ASSL_M_TLSV1_2_CLIENT, 0);
 	if (c == NULL)
 		assl_fatalx("assl_alloc_context");
 
@@ -35,6 +35,7 @@ main(int argc, char *argv[])
 
 	if (assl_connect(c, "localhost", ASSL_DEFAULT_PORT, ASSL_F_BLOCK))
 		assl_fatalx("assl_connect");
+	printf("cipher: %s\n", c->as_protocol);
 
 	wr = assl_write(c, buf, sizeof buf);
 	if (wr == -1)
